pub enum ServiceCardinality {
Single,
Multiple,
}Expand description
Declares whether a service key may have one or several providers.
Variants
Single
Exactly zero or one provider may be registered for this key.
Multiple
Any number of providers may be registered for this key.